@@ -8,12 +8,11 @@ from akerbp.mlops.core import logger, config
 service_name = config.envs.service_name
 logging=logger.get_logger("mlops_cdf")
 
-from akerbp.mlops.cdf.helpers import log_system_info
-log_system_info()
+service = import_module(f"akerbp.mlops.services.{service_name}").service
+
 
 def handle(data, secrets):
    try:
-      service = import_module(f"akerbp.mlops.services.{service_name}").service
       config.update_cdf_keys(secrets)
       return service(data, secrets)
    except Exception:
