@@ -20,6 +20,13 @@ logging=logger.get_logger(name='mlops_cdf')
 global_client = {}
 api_keys=config.api_keys
 
+env_vars = {k.upper():str(v) for k,v in config.envs_dic.items() if v}
+env_vars.update({'PLATFORM':'cdf'})
+try:
+    env_vars.pop('GOOGLE_PROJECT_ID')
+except KeyError:
+    pass
+
 
 def set_up_cdf_client(context='run'):
     """
@@ -89,8 +96,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
-    env_vars = {k.upper():v for k,v in config.envs_dir.items() if v}
-    env_vars.update(dict(DEPLOYMENT_PLATFORM='cdf'))
+    
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
@@ -102,7 +108,7 @@ def create_function(
         env_vars=env_vars
     )
     logging.debug(
-        f"Created {function_name}: {folder=}, {handler_path=}"
+        f"Created {function_name}: {folder=}, {handler_path=}, {env_vars=}"
     )
 
     return function
